@@ -2,6 +2,7 @@ import boto3
 from botocore.exceptions import WaiterError
 import yaml
 from datetime import datetime
+import simplejson as json
 
 from stackuchin.utilities import alert
 from stackuchin.utilities import result
@@ -10,7 +11,8 @@ import warnings
 warnings.filterwarnings("ignore")
 
 
-def update(profile_name, stack_file, stack_name, secret, slack_webhook_url, s3_bucket, s3_prefix, from_pipeline=False):
+def update(profile_name, stack_file, stack_name, secret, slack_webhook_url,
+           s3_bucket, s3_prefix, only_errors, from_pipeline=False):
     aws_region = None
     aws_account = None
     stacks = None
@@ -79,10 +81,14 @@ def update(profile_name, stack_file, stack_name, secret, slack_webhook_url, s3_b
     template = None
     try:
         with open(stacks[stack_name]['Template'], 'r') as template_stream:
-            template = yaml.safe_load(template_stream)
-    except yaml.YAMLError as exc:
-        print(exc)
-        exit(1)
+            template = json.load(template_stream)
+    except Exception as e:
+        try:
+            with open(stacks[stack_name]['Template'], 'r') as template_stream:
+                template = yaml.safe_load(template_stream)
+        except yaml.YAMLError as exc:
+            print(exc)
+            exit(1)
 
     if 'Resources' not in template:
         print("The CloudFormation templates provided for this stack does not contain any Resources")
@@ -139,8 +145,11 @@ def update(profile_name, stack_file, stack_name, secret, slack_webhook_url, s3_b
                                                     ClientToken=client_token,
                                                     ChangeSetName="Changeset-{}".format(client_token))
         else:
+            template_body = stack_template_url['value']
+            if type(template_body) != str:
+                template_body = json.dumps(template_body)
             changeset = cf_client.create_change_set(StackName=stack_name,
-                                                    TemplateBody=stack_template_url['value'],
+                                                    TemplateBody=template_body,
                                                     Parameters=stack_parameters,
                                                     Capabilities=[
                                                         'CAPABILITY_NAMED_IAM', 'CAPABILITY_IAM',
@@ -183,6 +192,9 @@ def update(profile_name, stack_file, stack_name, secret, slack_webhook_url, s3_b
         exit(1)
 
     # Waiting for stack to finish updating
+    if not only_errors:
+        print("UPDATE_STARTED for stack {}".format(stack_name))
+        alert(stack_name, None, aws_region, aws_account, "UPDATE_STARTED", profile_name, slack_webhook_url)
     waiter = None
     try:
         waiter = cf_client.get_waiter('stack_update_complete')
@@ -211,7 +223,8 @@ def update(profile_name, stack_file, stack_name, secret, slack_webhook_url, s3_b
               aws_region, aws_account, action, profile_name, slack_webhook_url)
         exit(1)
 
-    print("UPDATE_COMPLETE for stack {}".format(stack_name))
-    alert(stack_name, None, aws_region, aws_account, "UPDATE_COMPLETE", profile_name, slack_webhook_url)
+    if not only_errors:
+        print("UPDATE_COMPLETE for stack {}".format(stack_name))
+        alert(stack_name, None, aws_region, aws_account, "UPDATE_COMPLETE", profile_name, slack_webhook_url)
 
     return True
